Function from_filename
Source pub fn from_filename<P: AsRef<Path>>(filename: P) -> Result<Dotenv>
Create Dotenv from the specified file.
Searches upward from the current working directory for the given filename.
Errors
Returns Error::Io if the file is not found or cannot be read.